# v2: textgridy jsou lepeny nikoliv podle trvání textgridů, ale podle trvání zvuků

library(rPraat)

inputFolder <- "data"
listFiles <- list.files(path = inputFolder, pattern = "\\.TextGrid$" , ignore.case = TRUE)

casovyPosun <- 0
trvaniPrvniho <- 0

for (I in seq_along(listFiles)) {
    file <- listFiles[I]
    fileName <- substr(file, 1, nchar(file) - nchar(".TextGrid"))
    
    fileTextGrid <- paste0(inputFolder, "/", fileName, ".TextGrid")
    fileSound <- paste0(inputFolder, "/", fileName, ".wav")

    tg <- tg.read(fileTextGrid)
    snd <- snd.read(fileSound)
    
    if (I == 1) {  # první soubor
        tgAll  <- tg
        # trvaniPrvniho <- tg.getTotalDuration(tg)  $v1
        trvaniPrvniho <- snd$duration  # v2
        sndAll <- snd
        
        vrstvy <- names(tg)
        typVrstvy <- character(length(vrstvy))
        for (J in seqM(1, length(vrstvy))) {
            typVrstvy[J] <- tg[[J]]$type
        }
        
    } else {
        # lepení s posuny časů
        # rozlišit intervalovou a bodovou tier...
        
        for (J in seqM(1, length(vrstvy))) {
            if (is.null(tg[[vrstvy[J]]])) {
                stop(paste0("Missing tier [file: ", fileTextGrid, " tier: ", vrstvy[J],  "]"))
            }
            
            if (tg[[vrstvy[J]]]$type != typVrstvy[J]) {
                stop(paste0("Inconsistent tier type [file: ", fileTextGrid, " tier: ", vrstvy[J],  "]"))
            }
            
            if (tg[[vrstvy[J]]]$type == "interval") {
                tgAll[[vrstvy[J]]]$t1    <- c(tgAll[[vrstvy[J]]]$t1,    tg[[vrstvy[J]]]$t1 + casovyPosun)
                tgAll[[vrstvy[J]]]$t2    <- c(tgAll[[vrstvy[J]]]$t2,    tg[[vrstvy[J]]]$t2 + casovyPosun)
                tgAll[[vrstvy[J]]]$label <- c(tgAll[[vrstvy[J]]]$label, tg[[vrstvy[J]]]$label)
            } else if (tg[[vrstvy[J]]]$type == "point") {
                tgAll[[vrstvy[J]]]$t    <- c(tgAll[[vrstvy[J]]]$t,    tg[[vrstvy[J]]]$t + casovyPosun)
                tgAll[[vrstvy[J]]]$label <- c(tgAll[[vrstvy[J]]]$label, tg[[vrstvy[J]]]$label)
            } else {
                stop(paste0("Unknown tier type [file: ", fileTextGrid, " tier: ", vrstvy[J],  "]"))
            }
        }

        sndAll$sig <- rbind(sndAll$sig, snd$sig)
    }
    
    # casovyPosun <- casovyPosun + tg.getTotalDuration(tg)  # v1
    casovyPosun <- casovyPosun + snd$duration  # v2
}

class(tgAll)["tmax"] <- casovyPosun  # nastavení celkového trvání

tg.write(tgAll, "output/output.TextGrid")
snd.write(sndAll, "output/output.wav")

cat("Done.\n")
